export interface Comment {
    /** The string provided by the sender */
    author: string;
    content: string;
    created_at: string;
    /**
     * Needed for optimistic update.
     * When the comment is submitted, it is `'sending'`.
     * When the request succeeds and the comment is not hidden in the database, it turns into `'added'`.
     * When the request succeeds and the comment is hidden and awaiting approval, we receive `'delivered-awaiting-approval'`.
     * When the request fails, the status is `'failed'`. - You can use this information to prompt user to retry.
     */
    status?: CommentStatus;
}
/**
 * Needed for optimistic update.
 * When the comment is submitted, it is `'sending'`.
 * When the request succeeds and the comment is not hidden in the database, it turns into `'added'`.
 * When the request succeeds and the comment is hidden and awaiting approval, we receive `'delivered-awaiting-approval'`.
 * When the request fails, the status is `'failed'`. - You can use this information to prompt user to retry.
 */
export declare type CommentStatus = 'sending' | 'added' | 'delivered-awaiting-approval' | 'failed';
export interface UseCommentsError {
    error: string;
    details: string;
}
export interface UseCommentsConfig {
    limit?: number;
    offset?: number;
}
export interface UseComentsResult {
    comments: Comment[];
    addComment: ({ content, author, }: Pick<Comment, 'content' | 'author'>) => void;
    refetch: () => void;
    count: number;
    loading: boolean;
    error: UseCommentsError | null;
}
/**
 * Fetches comments from Hasura backend specified in `hasuraUrl` on mount and whenever
 * `config.limit` or `config.offset` change.
 *
 * @param hasuraUrl URL of the Hasura instance
 * @param postId Comments will be fetched for the post with id `postId`
 * @param config Configurable offset and limit for the GraphQL query to Hasura
 * @returns comments for giben post, aggregated count of all comments, error,
 *          loading state and a function to refetch data from backend.
 */
export declare const useComments: (hasuraUrl: string, postId: string, config?: UseCommentsConfig | undefined) => UseComentsResult;
